@@ -349,8 +349,8 @@ class language_learner:
         # print(input_text)
 
 
-        cols = 15
-        rows =ceil(n/cols)
+        cols = 20
+        rows =ceil(len(self.input_text)/cols)
 
 
         # if cols>7:
@@ -362,23 +362,24 @@ class language_learner:
         # self.top.geometry(str(lenghth)+"x"+str(width)+"+400+100")
         # print(x)
         button_size = 28
+        i = 0
         for j in range(rows+1):
+            print('j:',j,'n',n)
             width = 0
-            for i in range(cols):
-                if n>0:
-                    t = text_display_button(root = self.top,
-                    input_text=self.seg_list[i+j*cols],
-                    button_size = button_size,
-                    path_name=self.path_source)
-                    # t.grid(row=j+1, column=i)
-                    print(self.seg_list[i+j*cols])
-
-                    t.place(relx=0.05+width*0.043, rely=0.25+j*0.12)
-                    width += len(self.seg_list[i+j*cols])
-                    # t.place(relx=0.05+i*0.06, rely=0.25+j*0.12)
-                    self.button_object_list.append(t)
-                    n = n-1
+            while width < cols and i<n:
+                print('word,index,width,i,j',self.seg_list[i],i+j*cols,width,i,j)
+                t = text_display_button(root = self.top,
+                input_text=self.seg_list[i],
+                button_size = button_size,
+                path_name=self.path_source)
+                # t.grid(row=j+1, column=i)
+                # print(self.seg_list[i+j*cols])
 
+                t.place(relx=0.05+width*0.043, rely=0.25+j*0.12)
+                width += len(self.seg_list[i])
+                # t.place(relx=0.05+i*0.06, rely=0.25+j*0.12)
+                self.button_object_list.append(t)
+                i += 1
     def create_label_word(self):
 
         self.label_word = tk.Label(self.top,wraplengt=int(self.top_width*0.99),justify=LEFT)
@@ -950,7 +951,7 @@ class language_learner:
         return language_type
     def read(self,read_text):
         language_type = self.check_language_type(read_text)
-        var = gTTS(text = read_text,lang = language_type)
+        var = gTTS(text = read_text,lang = language_type,slow = True)
 
         audio_fname = os.path.join(self.source_path,read_text+'.mp3')
         # print(os.path.isfile(fname))
